/*
 * libslb.h - internal header file.
 * Used only when compiling the shared library code,
 * to redirect standard library functions to the
 * library that was linked to the application
 *
 * Copyright (C) 2019 Thorsten Otto
 */

#ifndef __BZIP2SLB_H__
#define __BZIP2SLB_H__ 1

#include <stdio.h>
#include <fcntl.h>
#include <errno.h>
#include <string.h>
#include <stdlib.h>
#include <time.h>
#include <math.h>
#include <setjmp.h>
#include <unistd.h>

#undef stderr
#undef stdout
#undef stdin

#undef memset
#undef memcpy
#undef memcmp
#undef memmove

#undef strlen
#undef strcpy
#undef strcat
#undef strcmp

#undef malloc
#undef free

#undef fopen
#undef fdopen
#undef fclose
#undef fflush
#undef feof
#undef fread
#undef fwrite
#undef sprintf
#undef printf
#undef fprintf

#include "libstrct.h"

#define stderr (bzip2_get_slb_funcs()->stderr_location)
#define stdout (bzip2_get_slb_funcs()->stdout_location)
#define stdin (bzip2_get_slb_funcs()->stdin_location)

#define memset(d, c, l) bzip2_get_slb_funcs()->p_memset(d, c, l)
#define memcpy(d, s, l) bzip2_get_slb_funcs()->p_memcpy(d, s, l)
#define memmove(d, s, l) bzip2_get_slb_funcs()->p_memcpy(d, s, l)
#define memcmp(d, s, l) bzip2_get_slb_funcs()->p_memcmp(d, s, l)

#define strlen bzip2_get_slb_funcs()->p_strlen
#define strcpy bzip2_get_slb_funcs()->p_strcpy
#define strcat bzip2_get_slb_funcs()->p_strcat
#define strcmp bzip2_get_slb_funcs()->p_strcmp

#define malloc bzip2_get_slb_funcs()->p_malloc
#define free(p) bzip2_get_slb_funcs()->p_free(p)

#define fopen bzip2_get_slb_funcs()->p_fopen
#define fdopen bzip2_get_slb_funcs()->p_fdopen
#define fclose bzip2_get_slb_funcs()->p_fclose
#define fflush bzip2_get_slb_funcs()->p_fflush
#define feof bzip2_get_slb_funcs()->p_feof
#define fread bzip2_get_slb_funcs()->p_fread
#define fwrite bzip2_get_slb_funcs()->p_fwrite
#define sprintf bzip2_get_slb_funcs()->p_sprintf
#define printf bzip2_get_slb_funcs()->p_printf
#define fprintf bzip2_get_slb_funcs()->p_fprintf

#endif /* __BZIP2SLB_H__ */
